netapp_ontap.models.nis API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.nis`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class NisSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the Nis object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `mapentry: str GET POST PATCH`

    RFC 2307 nisMapEntry attribute.

    Example: msSFU30NisMapEntry

  `mapname: str GET POST PATCH`

    RFC 2307 nisMapName attribute.

    Example: msSFU30NisMapName

  `netgroup: str GET POST PATCH`

    RFC 2307 nisNetgroup object class.

    Example: msSFU30NisNetGroup

  `netgroup_triple: str GET POST PATCH`

    RFC 2307 nisNetgroupTriple attribute.

    Example: msSFU30MemberOfNisNetgroup

  `object: str GET POST PATCH`

    RFC 2307 nisObject object class.

    Example: msSFU30NisObject